SWDEV-329567 - Fixes timing issu seen on Jenkins rns (#2628)

Change-Id: I7b4858033c58cba0c42a8ba8024f9b356e397658
This commit is contained in:
ROCm CI Service Account
2022-04-26 01:45:17 +05:30
committed by GitHub
parent 2ad9b91175
commit 427ba9156a
@@ -86,6 +86,7 @@ static inline void hipCheckAndFail(hipError_t errval,
do { hipCheckAndFail((errval), __FILE__, __LINE__); } while (0)
__global__ void test_kernel(uint32_t loops, unsigned long long *array, long long totalTicks) {
cooperative_groups::thread_block tb = cooperative_groups::this_thread_block();
unsigned int rank = blockIdx.x * blockDim.x + threadIdx.x;
for (int i = 0; i < loops; i++) {
@@ -100,6 +101,7 @@ __global__ void test_kernel(uint32_t loops, unsigned long long *array, long long
// So just ignore those slipped cycles.
last_clock = cur_clock;
} while(time_diff < totalTicks);
tb.sync();
array[rank] += clock64();
}
}